@@ -753,7 +753,7 @@ class ValiotWorker():
                     self.log(LogLevel.WARNING,
                              f"{job['queue']['name']} is DISABLED, skipping job")
         else:
-            self.log(LogLevel.INFO, "Listening to events...")
+            pass # nothing to do (no jobs), left here just to be explicit
 
     def abortStaleJobs(self):
         """This function aborts all stale jobs.
@@ -1300,7 +1300,7 @@ class ValiotWorker():
         if self.loggingStyle == LogStyle.JSON:
             # as we log this in JSON format, it can be human-readable
             W = self.worker["code"]
-            Q = __.get(queue, 'code', "WORKER_PROCESS")
+            Q = __.get(queue, 'name', "WORKER_PROCESS")
             J = __.get(job, 'id', 0)
 
             def sendLogToQueue(level, message, extra={}):
@@ -1402,7 +1402,7 @@ class ValiotWorker():
             if self.pollingMode == PollingMode.QUERY:
                 self.processJobs()
             else:
-                self.log(LogLevel.INFO, 'Listening to events...')
+                pass # subscription doesn't need to process jobs manually, but be explicit about it
             if self.useRedis:
                 self.redis.monitorRedisSubscriptions()
             self.monitorContinuousJobs()
